@@ -276,11 +276,11 @@ class JaggedArray(awkward.array.base.AwkwardArrayWithContent):
             return self.copy(content=self._content.ones_like(**overrides))
 
     def __awkward_serialize__(self, serializer):
-        if self._canuseoffset():
+        if self._canuseoffset() and len(self) > 0:
             return serializer.encode_call(
                 ["awkward", "JaggedArray", "fromcounts"],
                 serializer(self.counts, "JaggedArray.counts"),
-                serializer(self._content, "JaggedArray.content"),
+                serializer(self._content[self._starts[0]:self._stops[-1]], "JaggedArray.content"),
             )
         else:
             return serializer.encode_call(
@@ -1308,6 +1308,7 @@ class JaggedArray(awkward.array.base.AwkwardArrayWithContent):
         right = other._starts[parents] + iop - ocp * iop_ocp
 
         out = self.JaggedArray.fromoffsets(offsets, self.Table.named("tuple", left, right))
+        out._offsets = offsets
         out._parents = parents
         return out
 
